@@ -1,13 +1,13 @@
-from reamber.base.lists.notes.NoteList import NoteList
-from typing import List, Type
 from abc import ABC
+from typing import List, Type
 
-from reamber.osu.OsuNoteObjMeta import OsuNoteObjMeta
+from reamber.base.lists.notes.NoteList import NoteList
+from reamber.osu.OsuNoteMeta import OsuNoteMeta
 from reamber.osu.OsuSampleSet import OsuSampleSet
 
 
 class OsuNoteList(NoteList, ABC):
-    def data(self) -> List[Type[OsuNoteObjMeta]]: pass
+    def data(self) -> List[Type[OsuNoteMeta]]: pass
 
     def volumes(self) -> List[float]:
         return self.attribute('volume')
