@@ -1,11 +1,13 @@
 from __future__ import annotations
-from reamber.quaver.lists.notes.QuaNoteList import QuaNoteList
-from reamber.quaver.QuaHoldObj import QuaHoldObj
-from reamber.base.lists.notes.HoldList import HoldList
+
 from typing import List
 
+from reamber.base.lists.notes.HoldList import HoldList
+from reamber.quaver.QuaHold import QuaHold
+from reamber.quaver.lists.notes.QuaNoteList import QuaNoteList
 
-class QuaHoldList(List[QuaHoldObj], QuaNoteList, HoldList):
+
+class QuaHoldList(List[QuaHold], HoldList, QuaNoteList):
 
     def _upcast(self, objList: List = None) -> QuaHoldList:
         """ This is to facilitate inherited functions to work
@@ -15,5 +17,8 @@ class QuaHoldList(List[QuaHoldObj], QuaNoteList, HoldList):
         """
         return QuaHoldList(objList)
 
-    def data(self) -> List[QuaHoldObj]:
+    def multOffset(self, by: float, inplace:bool = False):
+        HoldList.multOffset(self, by=by, inplace=inplace)
+
+    def data(self) -> List[QuaHold]:
         return self
