@@ -1,11 +1,13 @@
 from __future__ import annotations
+
+from typing import Dict, overload
+
 from reamber.base.lists.NotePkg import NotePkg
 from reamber.sm.lists.notes import *
-from typing import Dict, overload
 
 
 class SMNotePkg(NotePkg):
-    """ This package holds hits, holds, rolls, mines, lifts, fakes, keySounds for each SMMapObj """
+    """ This package holds hits, holds, rolls, mines, lifts, fakes, keySounds for each SMMap """
 
     @overload
     def __init__(self): ...
