@@ -1,10 +1,12 @@
 from __future__ import annotations
-from reamber.sm.lists.notes.SMNoteList import SMNoteList
-from reamber.sm.SMKeySoundObj import SMKeySoundObj
+
 from typing import List
 
+from reamber.sm.SMKeySound import SMKeySound
+from reamber.sm.lists.notes.SMNoteList import SMNoteList
 
-class SMKeySoundList(List[SMKeySoundObj], SMNoteList):
+
+class SMKeySoundList(List[SMKeySound], SMNoteList):
 
     def _upcast(self, objList: List = None) -> SMKeySoundList:
         """ This is to facilitate inherited functions to work
@@ -14,5 +16,5 @@ class SMKeySoundList(List[SMKeySoundObj], SMNoteList):
         """
         return SMKeySoundList(objList)
 
-    def data(self) -> List[SMKeySoundObj]:
+    def data(self) -> List[SMKeySound]:
         return self
