@@ -10,16 +10,15 @@ from tests.test.RSC_PATHS import *
 # logging.basicConfig(filename="event.log", filemode="w+", level=logging.DEBUG)
 
 
-class TestQuaToSm(unittest.TestCase):
+class TestQuaToSM(unittest.TestCase):
 
     # @profile
-    def test_qua1(self):
+    def test(self):
         # Complex BPM Points
-        qua = QuaMap()
-        qua.readFile(QUA_NEURO_CLOUD)
+        qua = QuaMap.readFile(QUA_NEURO_CLOUD)
 
         sm = QuaToSM.convert(qua)
-        sm.writeFile("out.sm")
+        # sm.writeFile("out.sm")
 
 
 if __name__ == '__main__':
