@@ -10,8 +10,7 @@ class TestIO(unittest.TestCase):
 
     def testSv(self):
         # Complex BPM Points
-        osu = OsuMap()
-        osu.readFile(OSU_CARAVAN)
+        osu = OsuMap.readFile(OSU_CARAVAN)
 
         seq = SvSequence()
         seq.readSvFromMap(osu)
@@ -23,8 +22,7 @@ class TestIO(unittest.TestCase):
 
     def testTrueSv(self):
         # Complex BPM Points
-        osu = OsuMap()
-        osu.readFile(OSU_CARAVAN)
+        osu = OsuMap.readFile(OSU_CARAVAN)
 
         seq = SvSequence()
         seq.readTrueSvFromMap(osu, 140)
